// BHOCOP Version 1.0
// Copyright (c) 2001 Ziff Davis Media, Inc.
// All rights reserved.
// First Published in PC Magazine, US Edition, May 22, 2001.
// Programmer: Patrick Philippot

#if !defined(AFX_BHOCOPDLG_H__F09237EB_FB5F_11D4_91D3_00A0CCD36535__INCLUDED_)
#define AFX_BHOCOPDLG_H__F09237EB_FB5F_11D4_91D3_00A0CCD36535__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "StringExt.h"

/////////////////////////////////////////////////////////////////////////////
// CBHOCopDlg dialog

#define	CLSID_LEN			38
#define	MAX_CLSID_LEN		40
#define MAX_CONFNAME_LEN	50
#define MAX_VER_LEN			25

#define MIN_FRAME_SIZEX 400
#define MIN_FRAME_SIZEY 240

#define IDI_START			IDI_ENABLED

typedef enum
{
	BHO_STATE_ENABLED	= 	IDI_ENABLED - IDI_START,
	BHO_STATE_DISABLED	=	IDI_DISABLED - IDI_START,
	BHO_STATE_WARNING	=	IDI_BADINSTALL - IDI_START,
	BHO_STATE_BROKEN	=	IDI_BROKEN - IDI_START
}
BHO_STATE_CODE;

typedef enum
{
	BHO_CHECK_OK,
	BHO_CHECK_WARNING,
	BHO_CHECK_BROKEN
}
BHO_CHECK_CODE;

typedef enum 
{
	OS_WIN_NT	    = 0x1,
	OS_WIN_2000	    = 0x2,
	OS_WIN_1998	    = 0x4,
	OS_WIN_1995	    = 0x8,
	OS_WIN_32	    = 0x16,
	OS_WIN_NONE		= 0x32
} enumOS;


#define	BHO_COLUMN_NAME		0
#define	BHO_COLUMN_INFO		1
#define	BHO_COLUMN_VERSION	2
#define	BHO_COLUMN_PATH		3
#define	BHO_COLUMN_CLSID	4

class CBHOCopDlg : public CDialog
{
// Construction
public:
	CBHOCopDlg(CWnd* pParent = NULL);	// standard constructor

	BOOL			m_bQuiet;

// Dialog Data
	//{{AFX_DATA(CBHOCopDlg)
	enum { IDD = IDD_BHOCOP_DIALOG };
	CListCtrl	m_lstBHO;
	//}}AFX_DATA

	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CBHOCopDlg)
	public:
	virtual void WinHelp(DWORD dwData, UINT nCmd = HELP_CONTEXT);
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);	// DDX/DDV support
	//}}AFX_VIRTUAL

// Implementation
protected:
	HICON m_hIcon;

	// Generated message map functions
	//{{AFX_MSG(CBHOCopDlg)
	virtual BOOL OnInitDialog();
	afx_msg void OnSysCommand(UINT nID, LPARAM lParam);
	afx_msg void OnPaint();
	afx_msg HCURSOR OnQueryDragIcon();
	afx_msg void OnAppAbout();
	afx_msg void OnDestroy();
	afx_msg void OnFileSaveCfgAs();
	afx_msg void OnFileLoadCfg();
	afx_msg void OnFileExit();
	afx_msg void OnItemEnable();
	afx_msg void OnItemRemove();
	afx_msg void OnUpdateItemEnable(CCmdUI* pCmdUI);
	afx_msg void OnUpdateItemRemove(CCmdUI* pCmdUI);
	afx_msg void OnContextMenu(CWnd* pWnd, CPoint point);
	afx_msg void OnUpdateFileLoadCfg(CCmdUI* pCmdUI);
	afx_msg void OnUpdateFileSaveCfg(CCmdUI* pCmdUI);
	afx_msg void OnUpdateFileSaveCfgAs(CCmdUI* pCmdUI);
	afx_msg void OnDblclkBhoList(NMHDR* pNMHDR, LRESULT* pResult);
	afx_msg void OnSize(UINT nType, int cx, int cy);
	afx_msg void OnClickBhoList(NMHDR* pNMHDR, LRESULT* pResult);
	afx_msg BOOL OnEraseBkgnd(CDC* pDC);
	afx_msg void OnGetMinMaxInfo(MINMAXINFO *lpMMI);
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()

	void OnInitMenuPopup(CMenu *pPopupMenu, UINT nIndex,BOOL bSysMenu);
	void StoreOsVersion();

	CStringEx		m_sIniFilename;			// INI filename
	CStringEx		m_sRescueFilename;		// Rescue filename
	CString			m_sLastConf;			// Last current configuration
	CImageList		m_imgState;				// Image list for BHO list view

	CStringArray	m_ToBeDeleted;			// List of items to be deleted after enumeration
	
	BOOL			m_bCanAccess;			// FALSE if read-only mode
	BOOL			m_bChanged;				// TRUE if a modification has been made
	enumOS			m_OS;					// OS version

	int				m_nRightOffsetExit;		// Offsets used when removing
	int				m_nRightOffsetHelp;
	int				m_nBottomOffsetExit;
	int				m_nBottomOffsetConf;
	int				m_nListOffsetH;
	int				m_nListOffsetV;
	BOOL			m_bSizeInit;			// TRUE if offsets have been calculated
	int				m_nLastSel;				// Helper holding an item index

	//Helpers
	int AddStateIcon(int nId);

	///////////////
	void			EnumBHOs();
	void			AddBHOToList(LPCTSTR lpszCLSID, LPSTR lpszBHOName, BOOL bEnabled);
	BHO_CHECK_CODE	CheckBHO(LPCTSTR lpszCLSID, CStringEx& sBHOObjectName, CStringEx& sInfo, CStringEx& sVersion, CStringEx& sPath);
	BOOL			LoadConfig(CString sConfigName);
	void			SaveConfig(CString sConfigName);

public:

	static TCHAR g_szFullBHOKey[];
	static TCHAR g_szBHOKey[];
	static TCHAR g_szIniName[];
	static TCHAR g_szRescueName[];
	static TCHAR g_szIniDisabledSection[];
	static TCHAR g_szIniOptSection[];
	static TCHAR g_szIniCfgSection[];
	static TCHAR g_szCLSID[];
	static TCHAR g_szAppId[];
	static TCHAR g_szLastConf[];
	static TCHAR g_szDefaultConfName[];
	static TCHAR g_szTrue[];
	static TCHAR g_szFalse[];
	static TCHAR g_szUnknown[];
	static TCHAR g_szLocationKey[];
	static TCHAR g_szTreatAs[];
	static TCHAR g_szRescueDone[];
	static TCHAR g_szPosSection[];
	static TCHAR g_szShowEntry[];
	static TCHAR g_szFlagsEntry[];
	static TCHAR g_szLeftEntry[];
	static TCHAR g_szRightEntry[];
	static TCHAR g_szTopEntry[];
	static TCHAR g_szBottomEntry[];
	static TCHAR g_szIconLabel[];
	static TCHAR g_szColumn0[];
	static TCHAR g_szColumn1[];
	static TCHAR g_szColumn2[];
	static TCHAR g_szColumn3[];
	static TCHAR g_szColumn4[];
	static TCHAR g_szActiveDesktopKey[];
	static TCHAR g_szWduKey[];
	static TCHAR g_szShellState[];
};

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ will insert additional declarations immediately before the previous line.

#endif // !defined(AFX_BHOCOPDLG_H__F09237EB_FB5F_11D4_91D3_00A0CCD36535__INCLUDED_)
